package android.usp.ime.tcc.newbatataquente;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.FutureTask;
import java.util.concurrent.TimeUnit;

import usp.ime.gclib.net.wifi.NetworkAvailable;
import usp.ime.gclib.net.wifi.NetworkManager;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.usp.ime.tcc.geocommunication.Parameters;
import android.usp.ime.tcc.listView.AdapterListView;
import android.usp.ime.tcc.listView.ItemListView;
import android.usp.ime.tcc.soundVibrator.PlaySound;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

public class ListGameAvailableActivity extends Activity {

	private NetworkManager netMng;
	
	private ListView listView;
	private AdapterListView adapterListView;
	private ArrayList<ItemListView> itens;
	
	private TextView tvListNetworks;
	private TextView tvPlayerName;
	
	private PlaySound soundPool;

	private Parameters parameters;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_list_game_available);
        
        soundPool = new PlaySound(this);
        soundPool.initSound(R.raw.tique);
        
        parameters = Parameters.getInstance(null);
        
        listView = (ListView) findViewById(R.id.networkList);
        tvListNetworks = (TextView) findViewById(R.id.tvTitleListNetworks);
        tvPlayerName = (TextView) findViewById(R.id.playerName);
        
        tvPlayerName.setText(parameters.getDevice().getNick());
        
        listView.setOnItemClickListener(new OnItemClickListener() {

			public void onItemClick(AdapterView<?> arg0, View arg1, int position, long arg3) {
				if(soundPool.isLoaded())
					soundPool.play();
				ItemListView item = adapterListView.getItem(position);
				showDialogPassword(concatSsid(item.getTextCreaterName(), item.getTextGameName()));
			}
		});
        
        tvListNetworks.setText(getResources().getString(R.string.gameAvailable));
        
        itens = new ArrayList<ItemListView>();
        
        netMng = new NetworkManager(ListGameAvailableActivity.this);
        netMng.searchNetworks();
        
        startListView();
    }
    
    public boolean onCreateOptionsMenu(Menu menu) {
        menu.add(0, 0, 0, "Atualiza jogos").setIcon(R.drawable.refresh);
        return super.onCreateOptionsMenu(menu);
    }

    public boolean onMenuItemSelected(int featureId, MenuItem item) {
        netMng.searchNetworks();
        startListView();
        return super.onMenuItemSelected(featureId, item);
    }
    
	private void startListView() {
    	List<NetworkAvailable> nets = netMng.getAllNetworksAvailable();
		
    	itens.clear();
    	
    	if(nets == null){
			Toast.makeText(ListGameAvailableActivity.this, "O Wi-fi deve estar ligado", Toast.LENGTH_SHORT).show();
			tvListNetworks.setText(getResources().getString(R.string.wifiMustOn));
    	}
		else if(nets.isEmpty()){
			Toast.makeText(ListGameAvailableActivity.this, "Nenhum jogo encontrado", Toast.LENGTH_SHORT).show();
			tvListNetworks.setText(getResources().getString(R.string.noGameAvailable));
		}
		else {
			tvListNetworks.setText(getResources().getString(R.string.gameAvailable));
			for (NetworkAvailable net : nets) {
				String[] s = new String[2];
				s = parseSsid(net.getSSID());
				ItemListView item = new ItemListView(s[1], s[0]);
				itens.add(item);
			}
		}
        
        adapterListView = new AdapterListView(this, itens);
        listView.setAdapter(adapterListView);
    }
    
    private String[] parseSsid(String ssid) {
    	String[] s = ssid.split("_", 2);
		return s;
	}
    
    private String concatSsid(String criator, String gameName) {
    	return criator + "_" + gameName;
    }

	public void showDialogPassword(final String ssid) {
    	AlertDialog.Builder builder = new AlertDialog.Builder(this);
		final AlertDialog alert;
		
		LayoutInflater inflater = getLayoutInflater();
		
		View layout = inflater.inflate(R.layout.dialog_put_password, (ViewGroup) findViewById(R.id.allViewDialog));
		
		builder.setView(layout);
		builder.create();
		alert = builder.show();

		CheckBox cbShowPassword = (CheckBox) layout.findViewById(R.id.showPassword);
		final Button bOk = (Button) layout.findViewById(R.id.buttonEntrar);
		final EditText etPassword = (EditText) layout.findViewById(R.id.password);
		etPassword.addTextChangedListener(new TextWatcher() {
			
			public void onTextChanged(CharSequence arg0, int arg1, int arg2, int arg3) {
				if(etPassword.length() >= 8)
					bOk.setEnabled(true);
				else
					bOk.setEnabled(false);
			}
			
			public void beforeTextChanged(CharSequence arg0, int arg1, int arg2, int arg3) {
				
			}
			
			public void afterTextChanged(Editable arg0) {
				
			}
		});
		
		bOk.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				alert.dismiss();
				alert.cancel();
				
				showProgressBar();
				
				netMng.connectNetwork(new NetworkAvailable(ssid, false), etPassword.getText().toString());
			}
		});
		
		cbShowPassword.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
				if(isChecked)
					etPassword.setInputType(InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD);
				else 
					etPassword.setInputType(InputType.TYPE_CLASS_TEXT | InputType.TYPE_TEXT_VARIATION_PASSWORD);
			}
		});
    }
	
	private void showProgressBar() {
		final ProgressDialog progress = ProgressDialog.show(ListGameAvailableActivity.this, "", "Conectando ao jogo", true, true);
		
		new Thread() {
			public void run() {
				FutureTask<?> myTask;
				
				myTask = new FutureTask<Object>(new Runnable() {
					
					public void run() {
						try {
							sleep(4000);
						}
						catch(Exception e) {
							e.printStackTrace();
						}
						while(!netMng.isConnect()){
							
						}
						progress.dismiss();
						if(netMng.isConnect()) {
							parameters.getDevice().setAccessPoint(false);
							Intent i = new Intent(ListGameAvailableActivity.this, BatataQuenteActivity.class);
							startActivityForResult(i, 0);
						}
					}
				}, null);
				
				new Thread(myTask).start();
				
				try {
					myTask.get(20L, TimeUnit.SECONDS);
				} catch (Exception e) {
					myTask.cancel(true);
					progress.dismiss();
					e.printStackTrace();
				}
			}
		}.start();
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		netMng.removeNetwork();
		finish();
	}
}
