package android.usp.ime.tcc.newbatataquente;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.usp.ime.tcc.geocommunication.Parameters;
import android.usp.ime.tcc.soundVibrator.PlaySound;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class MenuPrincipalActivity extends Activity  {

	private static String PREFERENCES = "Preferences";
	private static String nickSavedName = "nickSavedName";
	
	private Button tStartGame;
	private Button tJoinGame;
	private Button tConfigGame;
	private Button tInstGame;
	private Button tExitGame;
	private TextView tPlayer;
	
	private PlaySound soundPool;
	
	private Parameters parameters;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_menu_principal);
        
        parameters = Parameters.getInstance(null);
        
        soundPool = new PlaySound(this);
        soundPool.initSound(R.raw.tique);
        
        tStartGame = (Button) findViewById(R.id.startGame);
        tJoinGame = (Button) findViewById(R.id.joinGame);
        tConfigGame = (Button) findViewById(R.id.configGame);
        tInstGame = (Button) findViewById(R.id.intrGame);
        tExitGame = (Button) findViewById(R.id.exitGame);
        tPlayer = (TextView) findViewById(R.id.playerName);
        
        SharedPreferences sp = getSharedPreferences(PREFERENCES, 0);
        String nick = sp.getString(nickSavedName, "");
        if(nick.equals(""))
        	showDialogApelido(false);
        else {
        	tPlayer.setText(nick);
        	parameters.getDevice().setNick(nick);
        	showDialogSavedApelido(nick);
        }
        
        startClickableViews();
    }
    
    @Override
    public void onDestroy(){
    	super.onDestroy();
    	System.exit(0);
    }

	private void showDialogSavedApelido(String nickApelido) {
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		final AlertDialog alert;
		
		LayoutInflater inflater = getLayoutInflater();
		
		View layout = inflater.inflate(R.layout.dialog_saved_apelido, (ViewGroup) findViewById(R.id.allViewDialog));
		
		((TextView) layout.findViewById(R.id.apelidoSaved)).setText(nickApelido);
		
		builder.setCancelable(false);
		builder.setView(layout);
		builder.create();
		alert = builder.show();

		Button bChange = (Button) layout.findViewById(R.id.buttonChangeName);
		Button bOk = (Button) layout.findViewById(R.id.buttonOk);
		bOk.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				alert.dismiss();
				alert.cancel();
			}
		});
		
		bChange.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View arg0) {
				if(soundPool.isLoaded())
					soundPool.play();
				alert.dismiss();
				alert.cancel();
				showDialogApelido(true);
			}
		});
		
	}
	
	private void showProgressDialogLocation() {
		final ProgressDialog progress = ProgressDialog.show(this, "", getResources().getString(R.string.waitingGps), true, true);

		final Thread t = new Thread() {
			public void run() {
				while(!parameters.getDevice().getDeviceLocation().gpsIsReady()){

				}
				progress.cancel();
			}
		};
		t.start();
		
		progress.setOnCancelListener(new OnCancelListener() {
			
			public void onCancel(DialogInterface dialog) {
				String s;
				if(parameters.getDevice().getDeviceLocation().gpsIsReady())
					s = "GPS pronto";
				else
					s = "Sinal de GPS no encontrado";
				Toast.makeText(MenuPrincipalActivity.this, s, Toast.LENGTH_SHORT).show();
			}
		});

	}

	private void showDialogApelido(boolean isCancelable) {
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		final AlertDialog alert;
		
		LayoutInflater inflater = getLayoutInflater();
		
		View layout = inflater.inflate(R.layout.dialog_apelido, (ViewGroup) findViewById(R.id.allViewDialog));
		
		final EditText apelido = (EditText) layout.findViewById(R.id.apelido);
		
		builder.setCancelable(isCancelable);
		builder.setView(layout);
		builder.create();
		alert = builder.show();

		Button bSalvar = (Button) layout.findViewById(R.id.buttonSalvar);
		bSalvar.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				String nick = apelido.getText().toString(); 
				tPlayer.setText(nick);
				parameters.getDevice().setNick(nick);
				
				SharedPreferences sp = getSharedPreferences(PREFERENCES, 0);
				SharedPreferences.Editor editor = sp.edit();
				editor.putString(nickSavedName, nick);
				editor.commit();
				
				alert.dismiss();
				alert.cancel();
			}
		});
	}

	private void startClickableViews() {
		tStartGame.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				if(!parameters.getDevice().getDeviceLocation().gpsIsReady())
					showProgressDialogLocation();
				else {
					Intent i = new Intent(MenuPrincipalActivity.this, StartGameActivity.class);
					startActivity(i);
				}
			}
		});
		
		tJoinGame.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				if(!parameters.getDevice().getDeviceLocation().gpsIsReady())
					showProgressDialogLocation();
				else {
					Intent i = new Intent(MenuPrincipalActivity.this, ListGameAvailableActivity.class);
					startActivity(i);
				}
			}
		});
		
		tConfigGame.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				Intent i = new Intent(MenuPrincipalActivity.this, ConfigurationActivity.class);
				startActivity(i);
			}
		});
		
		tInstGame.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				Intent i = new Intent(MenuPrincipalActivity.this, InstrutionsActivity.class);
				startActivity(i);
			}
		});
		
		tExitGame.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				onBackPressed();
			}
		});
		
		tPlayer.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				showDialogSavedApelido(tPlayer.getText().toString());
			}
		});
	}
	
	@Override
	public void onBackPressed() {		
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		final AlertDialog alert;
		
		LayoutInflater inflater = getLayoutInflater();
		View layout = inflater.inflate(R.layout.dialog_exit, (ViewGroup) findViewById(R.id.allViewDialog));
		builder.setView(layout);
		builder.create();
		alert = builder.show();

		Button exit = (Button) layout.findViewById(R.id.buttonExit);
		Button stay = (Button) layout.findViewById(R.id.buttonStay);
		exit.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				alert.dismiss();
				alert.cancel();
				
				MenuPrincipalActivity.super.onBackPressed();
			}
		});
		stay.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View v) {
				if(soundPool.isLoaded())
					soundPool.play();
				alert.dismiss();
				alert.cancel();
			}
		});
	}
	
}
