package android.usp.ime.tcc.newbatataquente;

import java.util.concurrent.FutureTask;
import java.util.concurrent.TimeUnit;

import usp.ime.gclib.net.wifi.NetworkConfiguration;
import usp.ime.gclib.net.wifi.NetworkManager;
import usp.ime.gclib.net.wifi.NetworkState;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.usp.ime.tcc.geocommunication.Parameters;
import android.usp.ime.tcc.soundVibrator.PlaySound;
import android.usp.ime.tcc.soundVibrator.Vibration;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.TextView;

public class StartGameActivity extends Activity {

	private TextView tvPlayer;
	private EditText etSsid;
	private EditText etPassword;
	private CheckBox cbShowPassword;
	private Button bNext;
	
	private NetworkManager netMag;
	
	private PlaySound soundPool; 
	private Vibration vibrator;
	
	private boolean passwordLengthOk = false;
	private boolean ssidLengthOk = false;
	
	private Parameters parameters;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_start_game);
        
        parameters = Parameters.getInstance(null);
        
        soundPool = new PlaySound(this);
        soundPool.initSound(R.raw.tique);
        vibrator = new Vibration(this);
        
        tvPlayer = (TextView) findViewById(R.id.playerName);
        etSsid = (EditText) findViewById(R.id.ssid);
        etPassword = (EditText) findViewById(R.id.password);
        cbShowPassword = (CheckBox) findViewById(R.id.showPassword);
        bNext = (Button) findViewById(R.id.bNext);
        
        startViews();
    }


	private void startViews() {
		tvPlayer.setText(parameters.getDevice().getNick());
		
		cbShowPassword.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			public void onCheckedChanged(CompoundButton buttonView, boolean checked) {
				if(checked) {
					etPassword.setInputType(InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD);
				}
				else {
					etPassword.setInputType(InputType.TYPE_CLASS_TEXT | InputType.TYPE_TEXT_VARIATION_PASSWORD);
				}
			}
		});
		
		bNext.setOnClickListener(new View.OnClickListener() {
			
			public void onClick(View arg0) {
				vibrator.vibra(Vibration.MEDIUM_VIBRATION);
				if(soundPool.isLoaded())
					soundPool.play();
				
				bNext.setEnabled(false);
				
				netMag = new NetworkManager(StartGameActivity.this);
				NetworkConfiguration netConfig = new NetworkConfiguration();
				netConfig.setSSID(parameters.getDevice().getNick() + "_" + etSsid.getText().toString());
				netConfig.setPassword(etPassword.getText().toString());
				netConfig.setOpen(false);
				
				netMag.startNetwork(netConfig);
				
				showProgressDialog();
			}

		});
		
		etPassword.addTextChangedListener(new TextWatcher() {
			
			public void onTextChanged(CharSequence s, int start, int before, int count) {
				if(etPassword.length() >= 8) {
					passwordLengthOk = true;
					if(ssidLengthOk)
						bNext.setEnabled(true);
				}
				else {
					passwordLengthOk = false;
					bNext.setEnabled(false);
				}
			}
			
			public void beforeTextChanged(CharSequence s, int start, int count, int after) {
				
			}
			
			public void afterTextChanged(Editable s) {
				
			}
		});
		
		etSsid.addTextChangedListener(new TextWatcher() {
			
			public void onTextChanged(CharSequence s, int start, int before, int count) {
				if(etSsid.length() == 0) {
					ssidLengthOk = false;
					bNext.setEnabled(false);
				}
				else {
					ssidLengthOk = true;
					if(passwordLengthOk)
						bNext.setEnabled(true);
				}
			}
			
			public void beforeTextChanged(CharSequence s, int start, int count, int after) {
				
			}
			
			public void afterTextChanged(Editable s) {
				
			}
		});
	}
	
	private void showProgressDialog() {
		
		final ProgressDialog progress = ProgressDialog.show(this, "", getResources().getString(R.string.progress_dialog_wifi), true, false);

		new Thread() {
			public void run() {
				FutureTask<?> myTask;
				
				myTask = new FutureTask<Object>(new Runnable() {
					
					public void run() {
						while((netMag.getNetworkState() != NetworkState.ENABLED) ){
							
						}
						progress.dismiss();
						if(netMag.getNetworkState() == NetworkState.ENABLED) {
							parameters.getDevice().setAccessPoint(true);
							Intent i = new Intent(StartGameActivity.this, BatataQuenteActivity.class);
							startActivityForResult(i, 0);
						}
						else {
							bNext.setEnabled(true);
						}
					}
				}, null);
				
				new Thread(myTask).start();
				
				try {
					myTask.get(20L, TimeUnit.SECONDS);
				} catch (Exception e) {
					myTask.cancel(true);
					progress.dismiss();
					bNext.setEnabled(true);
					e.printStackTrace();
				}
			}
		}.start();
		
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		netMag.stopNetwork();
		finish();
	}
}
